<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Storage;use App\Page;

class PagesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pages = Page::all();
        return view('Backend.Pages.list')->with('pages',$pages);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('Backend.Pages.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = ['title' => 'required','description' => 'required'];

        $validation = $this->Validate($request,$rules);

        $page = Page::where('title','=',$request->title)->first();

        if(!$page)
        {
            $page = new Page;
            $page->title       = $request->title;
            $page->description = $request->description;

            // Save Page banner Image
            if($request->hasFile('banner'))
            {
                $image            = $request->file('banner'); 
                $filename         = rand(550,5500).'_'.time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/Page-Images';
                $image->storeAs($destination_path,$filename);
                $page->banner = $filename;
            }

            if($page->save())
            {    
                return redirect('page')->with('alert-success', 'Page Created Successfully');
            }
            else
            {
                return redirect('page/create')->with('alert-error', $validation->errors());
            }
        }
        else
        {
            return redirect('page/create')->with('alert-error', 'This Page Title Already Exist');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $page = Page::find($id);
        return view('Backend.Pages.show')->with('page',$page);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $page = Page::find($id);
        return view('Backend.Pages.edit')->with('page',$page);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = ['title' => 'required','description' => 'required'];

        $validation = $this->Validate($request,$rules);
        $page = Page::find($id);
        if($page)
        {
            $page->title       = $request->title;
            $page->description = $request->description;

            // Save Page banner Image
            if($request->hasFile('banner'))
            {
                $image            = $request->file('banner'); 
                $filename         = rand(550,5500).'_'.time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/Page-Images';
                $image->storeAs($destination_path,$filename);
                $page->banner = $filename;
            }

            if($page->update())
            {    
                return redirect('page')->with('alert-success', 'Page Updated Successfully');
            }
            else
            {
                return redirect('page/create')->with('alert-error', $validation->errors());
            }
        }
        else
        {
            return redirect('page')->with('alert-error', 'Page can not find');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $page = Page::find($id);
        if($page->delete())
        {    
            return redirect('page')->with('alert-error', 'Page Deleted Successfully');
        }
    }
}
